
# Slot: has employment history




URI: [ks:has_employment_history](https://w3id.org/linkml/tests/kitchen_sink/has_employment_history)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [EmploymentEvent](EmploymentEvent.md)

## Parents


## Children


## Used by

 * [Person](Person.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | subset B |

